@@ -19,7 +19,7 @@ struct _SnapdGetAssertions
 {
     SnapdRequest parent_instance;
     gchar *type;
-    gchar **assertions;
+    GStrv assertions;
 };
 
 G_DEFINE_TYPE (SnapdGetAssertions, snapd_get_assertions, snapd_request_get_type ())
@@ -39,7 +39,7 @@ _snapd_get_assertions_new (const gchar *type, GCancellable *cancellable, GAsyncR
     return request;
 }
 
-gchar **
+GStrv
 _snapd_get_assertions_get_assertions (SnapdGetAssertions *request)
 {
     return request->assertions;
@@ -58,7 +58,7 @@ generate_get_assertions_request (SnapdRequest *request)
 }
 
 static gboolean
-parse_get_assertions_response (SnapdRequest *request, SoupMessage *message, GError **error)
+parse_get_assertions_response (SnapdRequest *request, SoupMessage *message, SnapdMaintenance **maintenance, GError **error)
 {
     SnapdGetAssertions *r = SNAPD_GET_ASSERTIONS (request);
     const gchar *content_type;
@@ -71,7 +71,7 @@ parse_get_assertions_response (SnapdRequest *request, SoupMessage *message, GErr
         g_autoptr(JsonObject) response = NULL;
         g_autoptr(JsonObject) result = NULL;
 
-        response = _snapd_json_parse_response (message, error);
+        response = _snapd_json_parse_response (message, maintenance, error);
         if (response == NULL)
             return FALSE;
         result = _snapd_json_get_sync_result_o (response, error);
@@ -135,7 +135,7 @@ parse_get_assertions_response (SnapdRequest *request, SoupMessage *message, GErr
     }
     g_ptr_array_add (assertions, NULL);
 
-    r->assertions = g_steal_pointer ((gchar ***)&assertions->pdata);
+    r->assertions = g_steal_pointer ((GStrv *)&assertions->pdata);
 
     return TRUE;
 }
