@@ -15,7 +15,7 @@
 struct _SnapdGetSections
 {
     SnapdRequest parent_instance;
-    gchar **sections;
+    GStrv sections;
 };
 
 G_DEFINE_TYPE (SnapdGetSections, snapd_get_sections, snapd_request_get_type ())
@@ -30,7 +30,7 @@ _snapd_get_sections_new (GCancellable *cancellable, GAsyncReadyCallback callback
                                              NULL));
 }
 
-gchar **
+GStrv
 _snapd_get_sections_get_sections (SnapdGetSections *request)
 {
     return request->sections;
@@ -43,7 +43,7 @@ generate_get_sections_request (SnapdRequest *request)
 }
 
 static gboolean
-parse_get_sections_response (SnapdRequest *request, SoupMessage *message, GError **error)
+parse_get_sections_response (SnapdRequest *request, SoupMessage *message, SnapdMaintenance **maintenance, GError **error)
 {
     SnapdGetSections *r = SNAPD_GET_SECTIONS (request);
     g_autoptr(JsonObject) response = NULL;
@@ -51,7 +51,7 @@ parse_get_sections_response (SnapdRequest *request, SoupMessage *message, GError
     g_autoptr(GPtrArray) sections = NULL;
     guint i;
 
-    response = _snapd_json_parse_response (message, error);
+    response = _snapd_json_parse_response (message, maintenance, error);
     if (response == NULL)
         return FALSE;
     result = _snapd_json_get_sync_result_a (response, error);
@@ -73,7 +73,7 @@ parse_get_sections_response (SnapdRequest *request, SoupMessage *message, GError
     }
     g_ptr_array_add (sections, NULL);
 
-    r->sections = g_steal_pointer ((gchar ***)&sections->pdata);
+    r->sections = g_steal_pointer ((GStrv *)&sections->pdata);
 
     return TRUE;
 }
