@@ -15,14 +15,14 @@ struct _SnapdGetSnaps
 {
     SnapdRequest parent_instance;
     gchar *select;
-    gchar **names;
+    GStrv names;
     GPtrArray *snaps;
 };
 
 G_DEFINE_TYPE (SnapdGetSnaps, snapd_get_snaps, snapd_request_get_type ())
 
 SnapdGetSnaps *
-_snapd_get_snaps_new (GCancellable *cancellable, gchar **names, GAsyncReadyCallback callback, gpointer user_data)
+_snapd_get_snaps_new (GCancellable *cancellable, GStrv names, GAsyncReadyCallback callback, gpointer user_data)
 {
     SnapdGetSnaps *request;
 
@@ -81,13 +81,13 @@ generate_get_snaps_request (SnapdRequest *request)
 }
 
 static gboolean
-parse_get_snaps_response (SnapdRequest *request, SoupMessage *message, GError **error)
+parse_get_snaps_response (SnapdRequest *request, SoupMessage *message, SnapdMaintenance **maintenance, GError **error)
 {
     SnapdGetSnaps *r = SNAPD_GET_SNAPS (request);
     g_autoptr(JsonObject) response = NULL;
     g_autoptr(JsonArray) result = NULL;
 
-    response = _snapd_json_parse_response (message, error);
+    response = _snapd_json_parse_response (message, maintenance, error);
     if (response == NULL)
         return FALSE;
     result = _snapd_json_get_sync_result_a (response, error);
