@@ -323,20 +323,44 @@ snapd_client_get_snap_sync (SnapdClient *client,
  * Returns: (transfer container) (element-type SnapdApp): an array of #SnapdApp or %NULL on error.
  *
  * Since: 1.25
+ * Deprecated: 1.45: Use snapd_client_get_apps2_sync()
  */
 GPtrArray *
 snapd_client_get_apps_sync (SnapdClient *client,
                             SnapdGetAppsFlags flags,
                             GCancellable *cancellable, GError **error)
+{
+    return snapd_client_get_apps2_sync (client, flags, NULL, cancellable, error);
+}
+
+/**
+ * snapd_client_get_apps2_sync:
+ * @client: a #SnapdClient.
+ * @flags: a set of #SnapdGetAppsFlags to control what results are returned.
+ * @snaps: (allow-none): A list of snap names to return results for. If %NULL or empty then apps for all installed snaps are returned.
+ * @cancellable: (allow-none): a #GCancellable or %NULL.
+ * @error: (allow-none): #GError location to store the error occurring, or %NULL to ignore.
+ *
+ * Get information on installed apps.
+ *
+ * Returns: (transfer container) (element-type SnapdApp): an array of #SnapdApp or %NULL on error.
+ *
+ * Since: 1.45
+ */
+GPtrArray *
+snapd_client_get_apps2_sync (SnapdClient *client,
+                             SnapdGetAppsFlags flags,
+                             GStrv snaps,
+                             GCancellable *cancellable, GError **error)
 {
     g_auto(SyncData) data = { 0 };
 
     g_return_val_if_fail (SNAPD_IS_CLIENT (client), NULL);
 
     start_sync (&data);
-    snapd_client_get_apps_async (client, flags, cancellable, sync_cb, &data);
+    snapd_client_get_apps2_async (client, flags, snaps, cancellable, sync_cb, &data);
     end_sync (&data);
-    return snapd_client_get_apps_finish (client, data.result, error);
+    return snapd_client_get_apps2_finish (client, data.result, error);
 }
 
 /**
@@ -420,7 +444,7 @@ G_GNUC_END_IGNORE_DEPRECATIONS
  */
 GPtrArray *
 snapd_client_get_snaps_sync (SnapdClient *client,
-                             SnapdGetSnapsFlags flags, gchar **names,
+                             SnapdGetSnapsFlags flags, GStrv names,
                              GCancellable *cancellable, GError **error)
 {
     g_auto(SyncData) data = { 0 };
@@ -446,7 +470,7 @@ snapd_client_get_snaps_sync (SnapdClient *client,
  *
  * Since: 1.8
  */
-gchar **
+GStrv
 snapd_client_get_assertions_sync (SnapdClient *client,
                                   const gchar *type,
                                   GCancellable *cancellable, GError **error)
@@ -476,7 +500,7 @@ snapd_client_get_assertions_sync (SnapdClient *client,
  */
 gboolean
 snapd_client_add_assertions_sync (SnapdClient *client,
-                                  gchar **assertions,
+                                  GStrv assertions,
                                   GCancellable *cancellable, GError **error)
 {
     g_auto(SyncData) data = { 0 };
@@ -862,7 +886,7 @@ snapd_client_refresh_sync (SnapdClient *client,
  *
  * Since: 1.5
  */
-gchar **
+GStrv
 snapd_client_refresh_all_sync (SnapdClient *client,
                                SnapdProgressCallback progress_callback, gpointer progress_callback_data,
                                GCancellable *cancellable, GError **error)
@@ -1165,7 +1189,7 @@ snapd_client_get_users_sync (SnapdClient *client,
  *
  * Since: 1.7
  */
-gchar **
+GStrv
 snapd_client_get_sections_sync (SnapdClient *client,
                                 GCancellable *cancellable, GError **error)
 {
@@ -1324,7 +1348,7 @@ snapd_client_prefer_sync (SnapdClient *client,
  */
 gboolean
 snapd_client_enable_aliases_sync (SnapdClient *client,
-                                  const gchar *snap, gchar **aliases,
+                                  const gchar *snap, GStrv aliases,
                                   SnapdProgressCallback progress_callback, gpointer progress_callback_data,
                                   GCancellable *cancellable, GError **error)
 {
@@ -1352,7 +1376,7 @@ snapd_client_enable_aliases_sync (SnapdClient *client,
  */
 gboolean
 snapd_client_disable_aliases_sync (SnapdClient *client,
-                                   const gchar *snap, gchar **aliases,
+                                   const gchar *snap, GStrv aliases,
                                    SnapdProgressCallback progress_callback, gpointer progress_callback_data,
                                    GCancellable *cancellable, GError **error)
 {
@@ -1380,7 +1404,7 @@ snapd_client_disable_aliases_sync (SnapdClient *client,
  */
 gboolean
 snapd_client_reset_aliases_sync (SnapdClient *client,
-                                 const gchar *snap, gchar **aliases,
+                                 const gchar *snap, GStrv aliases,
                                  SnapdProgressCallback progress_callback, gpointer progress_callback_data,
                                  GCancellable *cancellable, GError **error)
 {
@@ -1407,7 +1431,7 @@ snapd_client_reset_aliases_sync (SnapdClient *client,
  */
 gboolean
 snapd_client_run_snapctl_sync (SnapdClient *client,
-                               const gchar *context_id, gchar **args,
+                               const gchar *context_id, GStrv args,
                                gchar **stdout_output, gchar **stderr_output,
                                GCancellable *cancellable, GError **error)
 {
