@@ -23,6 +23,8 @@
 #include <snapd-glib/snapd-error.h>
 #include <snapd-glib/snapd-icon.h>
 #include <snapd-glib/snapd-login.h>
+#include <snapd-glib/snapd-maintenance.h>
+#include <snapd-glib/snapd-media.h>
 #include <snapd-glib/snapd-plug.h>
 #include <snapd-glib/snapd-price.h>
 #include <snapd-glib/snapd-screenshot.h>
