@@ -14,6 +14,7 @@
 
 #include "snapd-error.h"
 #include "snapd-app.h"
+#include "snapd-media.h"
 #include "snapd-screenshot.h"
 #include "snapd-task.h"
 
@@ -291,6 +292,26 @@ parse_error_response (JsonObject *root, GError **error)
                              SNAPD_ERROR,
                              SNAPD_ERROR_AUTH_CANCELLED,
                              message);
+    else if (g_strcmp0 (kind, "snap-not-classic") == 0)
+        g_set_error_literal (error,
+                             SNAPD_ERROR,
+                             SNAPD_ERROR_NOT_CLASSIC,
+                             message);
+    else if (g_strcmp0 (kind, "snap-revision-not-available") == 0)
+        g_set_error_literal (error,
+                             SNAPD_ERROR,
+                             SNAPD_ERROR_REVISION_NOT_AVAILABLE,
+                             message);
+    else if (g_strcmp0 (kind, "snap-channel-not-available") == 0)
+        g_set_error_literal (error,
+                             SNAPD_ERROR,
+                             SNAPD_ERROR_CHANNEL_NOT_AVAILABLE,
+                             message);
+    else if (g_strcmp0 (kind, "snap-not-a-snap") == 0)
+        g_set_error_literal (error,
+                             SNAPD_ERROR,
+                             SNAPD_ERROR_NOT_A_SNAP,
+                             message);
     else {
         switch (status_code) {
         case SOUP_STATUS_BAD_REQUEST:
@@ -327,7 +348,7 @@ parse_error_response (JsonObject *root, GError **error)
 }
 
 JsonObject *
-_snapd_json_parse_response (SoupMessage *message, GError **error)
+_snapd_json_parse_response (SoupMessage *message, SnapdMaintenance **maintenance, GError **error)
 {
     const gchar *content_type;
     g_autoptr(JsonParser) parser = NULL;
@@ -365,6 +386,23 @@ _snapd_json_parse_response (SoupMessage *message, GError **error)
         return NULL;
     }
 
+    if (json_object_has_member (root, "maintenance") && maintenance != NULL) {
+        JsonObject *m = json_object_get_object_member (root, "maintenance");
+        const gchar *kind;
+        SnapdMaintenanceKind maintenance_kind = SNAPD_MAINTENANCE_KIND_UNKNOWN;
+
+        kind = _snapd_json_get_string (m, "kind", NULL);
+        if (g_strcmp0 (kind, "daemon-restart") == 0)
+            maintenance_kind = SNAPD_MAINTENANCE_KIND_DAEMON_RESTART;
+        else if (g_strcmp0 (kind, "system-restart") == 0)
+            maintenance_kind = SNAPD_MAINTENANCE_KIND_SYSTEM_RESTART;
+
+        *maintenance = g_object_new (SNAPD_TYPE_MAINTENANCE,
+                                     "kind", maintenance_kind,
+                                     "message", _snapd_json_get_string (m, "message", NULL),
+                                     NULL);
+    }
+
     if (strcmp (json_node_get_string (type_node), "error") == 0) {
         parse_error_response (root, error);
         return NULL;
@@ -604,6 +642,8 @@ _snapd_json_parse_snap (JsonObject *object, GError **error)
     g_autoptr(GPtrArray) channels_array = NULL;
     g_autoptr(JsonArray) common_ids = NULL;
     g_autoptr(GPtrArray) common_ids_array = NULL;
+    g_autoptr(JsonArray) media = NULL;
+    g_autoptr(GPtrArray) media_array = NULL;
     g_autoptr(GPtrArray) prices_array = NULL;
     g_autoptr(JsonArray) screenshots = NULL;
     g_autoptr(GPtrArray) screenshots_array = NULL;
@@ -713,6 +753,28 @@ _snapd_json_parse_snap (JsonObject *object, GError **error)
         }
     }
 
+    media = _snapd_json_get_array (object, "media");
+    media_array = g_ptr_array_new_with_free_func (g_object_unref);
+    for (i = 0; i < json_array_get_length (media); i++) {
+        JsonNode *node = json_array_get_element (media, i);
+        JsonObject *s;
+        g_autoptr(SnapdMedia) media = NULL;
+
+        if (json_node_get_value_type (node) != JSON_TYPE_OBJECT) {
+            g_set_error (error, SNAPD_ERROR, SNAPD_ERROR_READ_FAILED, "Unexpected media type");
+            return NULL;
+        }
+
+        s = json_node_get_object (node);
+        media = g_object_new (SNAPD_TYPE_MEDIA,
+                              "type", _snapd_json_get_string (s, "type", NULL),
+                              "url", _snapd_json_get_string (s, "url", NULL),
+                              "width", (guint) _snapd_json_get_int (s, "width", 0),
+                              "height", (guint) _snapd_json_get_int (s, "height", 0),
+                              NULL);
+        g_ptr_array_add (media_array, g_steal_pointer (&media));
+    }
+
     screenshots = _snapd_json_get_array (object, "screenshots");
     screenshots_array = g_ptr_array_new_with_free_func (g_object_unref);
     for (i = 0; i < json_array_get_length (screenshots); i++) {
@@ -775,10 +837,11 @@ _snapd_json_parse_snap (JsonObject *object, GError **error)
 
     return g_object_new (SNAPD_TYPE_SNAP,
                          "apps", apps_array,
+                         "base", _snapd_json_get_string (object, "base", NULL),
                          "broken", _snapd_json_get_string (object, "broken", NULL),
                          "channel", _snapd_json_get_string (object, "channel", NULL),
                          "channels", channels_array,
-                         "common-ids", (gchar **) common_ids_array->pdata,
+                         "common-ids", (GStrv) common_ids_array->pdata,
                          "confinement", confinement,
                          "contact", _snapd_json_get_string (object, "contact", NULL),
                          "description", _snapd_json_get_string (object, "description", NULL),
@@ -790,6 +853,8 @@ _snapd_json_parse_snap (JsonObject *object, GError **error)
                          "installed-size", _snapd_json_get_int (object, "installed-size", 0),
                          "jailmode", _snapd_json_get_bool (object, "jailmode", FALSE),
                          "license", _snapd_json_get_string (object, "license", NULL),
+                         "media", media_array,
+                         "mounted-from", _snapd_json_get_string (object, "mounted-from", NULL),
                          "name", name,
                          "prices", prices_array,
                          "private", _snapd_json_get_bool (object, "private", FALSE),
@@ -804,7 +869,7 @@ _snapd_json_parse_snap (JsonObject *object, GError **error)
                          "summary", _snapd_json_get_string (object, "summary", NULL),
                          "title", _snapd_json_get_string (object, "title", NULL),
                          "tracking-channel", _snapd_json_get_string (object, "tracking-channel", NULL),
-                         "tracks", (gchar **) track_array->pdata,
+                         "tracks", (GStrv) track_array->pdata,
                          "trymode", _snapd_json_get_bool (object, "trymode", FALSE),
                          "version", _snapd_json_get_string (object, "version", NULL),
                          NULL);
@@ -884,14 +949,14 @@ _snapd_json_parse_user_information (JsonObject *object, GError **error)
             g_ptr_array_add (discharge_array, (gpointer) json_node_get_string (node));
         }
         g_ptr_array_add (discharge_array, NULL);
-        auth_data = snapd_auth_data_new (_snapd_json_get_string (object, "macaroon", NULL), (gchar **) discharge_array->pdata);
+        auth_data = snapd_auth_data_new (_snapd_json_get_string (object, "macaroon", NULL), (GStrv) discharge_array->pdata);
     }
 
     return g_object_new (SNAPD_TYPE_USER_INFORMATION,
                          "id", _snapd_json_get_int (object, "id", -1),
                          "username", _snapd_json_get_string (object, "username", NULL),
                          "email", _snapd_json_get_string (object, "email", NULL),
-                         "ssh-keys", (gchar **) ssh_key_array->pdata,
+                         "ssh-keys", (GStrv) ssh_key_array->pdata,
                          "auth-data", auth_data,
                          NULL);
 }
