@@ -35,10 +35,11 @@ struct _SnapdSnap
     GObject parent_instance;
 
     GPtrArray *apps;
+    gchar *base;
     gchar *broken;
     gchar *channel;
     GPtrArray *channels;
-    gchar **common_ids;
+    GStrv common_ids;
     SnapdConfinement confinement;
     gchar *contact;
     gchar *description;
@@ -50,6 +51,8 @@ struct _SnapdSnap
     gint64 installed_size;
     gboolean jailmode;
     gchar *license;
+    GPtrArray *media;
+    gchar *mounted_from;
     gchar *name;
     GPtrArray *prices;
     gboolean private;
@@ -63,7 +66,7 @@ struct _SnapdSnap
     gchar *summary;
     gchar *title;
     gchar *tracking_channel;
-    gchar **tracks;
+    GStrv tracks;
     gboolean trymode;
     SnapdSnapType snap_type;
     gchar *version;
@@ -105,6 +108,9 @@ enum
     PROP_PUBLISHER_ID,
     PROP_PUBLISHER_USERNAME,
     PROP_PUBLISHER_VALIDATION,
+    PROP_BASE,
+    PROP_MOUNTED_FROM,
+    PROP_MEDIA,
     PROP_LAST
 };
 
@@ -127,13 +133,30 @@ snapd_snap_get_apps (SnapdSnap *snap)
     return snap->apps;
 }
 
+/**
+ * snapd_snap_get_base:
+ * @snap: a #SnapdSnap.
+ *
+ * Get the base snap this snap uses.
+ *
+ * Returns: (allow-none): a snap name or %NULL if not set.
+ *
+ * Since: 1.45
+ */
+const gchar *
+snapd_snap_get_base (SnapdSnap *snap)
+{
+    g_return_val_if_fail (SNAPD_IS_SNAP (snap), NULL);
+    return snap->base;
+}
+
 /**
  * snapd_snap_get_broken:
  * @snap: a #SnapdSnap.
  *
  * Get the reason this snap is broken.
  *
- * Returns: an error string or %NULL if not broken.
+ * Returns: (allow-none): an error string or %NULL if not broken.
  *
  * Since: 1.25
  */
@@ -253,7 +276,7 @@ snapd_snap_match_channel (SnapdSnap *snap, const gchar *name)
  *
  * Since: 1.41
  */
-gchar **
+GStrv
 snapd_snap_get_common_ids (SnapdSnap *snap)
 {
     g_return_val_if_fail (SNAPD_IS_SNAP (snap), NULL);
@@ -466,6 +489,41 @@ snapd_snap_get_license (SnapdSnap *snap)
     return snap->license;
 }
 
+/**
+ * snapd_snap_get_media:
+ * @snap: a #SnapdSnap.
+ *
+ * Get media that is associated with this snap.
+ *
+ * Returns: (transfer none) (element-type SnapdMedia): an array of #SnapdMedia.
+ *
+ * Since: 1.45
+ */
+GPtrArray *
+snapd_snap_get_media (SnapdSnap *snap)
+{
+    g_return_val_if_fail (SNAPD_IS_SNAP (snap), NULL);
+    return snap->media;
+}
+
+/**
+ * snapd_snap_get_mounted_from:
+ * @snap: a #SnapdSnap.
+ *
+ * Gets the path this snap is mounted from, which is a .snap file for installed
+ * snaps and a directory for snaps in try mode.
+ *
+ * Returns: (allow-none): a file path or %NULL.
+ *
+ * Since: 1.45
+ */
+const gchar *
+snapd_snap_get_mounted_from (SnapdSnap *snap)
+{
+    g_return_val_if_fail (SNAPD_IS_SNAP (snap), NULL);
+    return snap->mounted_from;
+}
+
 /**
  * snapd_snap_get_title:
  * @snap: a #SnapdSnap.
@@ -630,6 +688,7 @@ snapd_snap_get_revision (SnapdSnap *snap)
  * Returns: (transfer none) (element-type SnapdScreenshot): an array of #SnapdScreenshot.
  *
  * Since: 1.0
+ * Deprecated: 1.45: Use snapd_snap_get_media()
  */
 GPtrArray *
 snapd_snap_get_screenshots (SnapdSnap *snap)
@@ -716,7 +775,7 @@ snapd_snap_get_tracking_channel (SnapdSnap *snap)
  *
  * Since: 1.22
  */
-gchar **
+GStrv
 snapd_snap_get_tracks (SnapdSnap *snap)
 {
     g_return_val_if_fail (SNAPD_IS_SNAP (snap), NULL);
@@ -770,6 +829,10 @@ snapd_snap_set_property (GObject *object, guint prop_id, const GValue *value, GP
         if (g_value_get_boxed (value) != NULL)
             snap->apps = g_ptr_array_ref (g_value_get_boxed (value));
         break;
+    case PROP_BASE:
+        g_free (snap->base);
+        snap->base = g_strdup (g_value_get_string (value));
+        break;
     case PROP_BROKEN:
         g_free (snap->broken);
         snap->broken = g_strdup (g_value_get_string (value));
@@ -819,9 +882,14 @@ snapd_snap_set_property (GObject *object, guint prop_id, const GValue *value, GP
     case PROP_JAILMODE:
         snap->jailmode = g_value_get_boolean (value);
         break;
-    case PROP_TITLE:
-        g_free (snap->title);
-        snap->title = g_strdup (g_value_get_string (value));
+    case PROP_MOUNTED_FROM:
+        g_free (snap->mounted_from);
+        snap->mounted_from = g_strdup (g_value_get_string (value));
+        break;
+    case PROP_MEDIA:
+        g_clear_pointer (&snap->media, g_ptr_array_unref);
+        if (g_value_get_boxed (value) != NULL)
+            snap->media = g_ptr_array_ref (g_value_get_boxed (value));
         break;
     case PROP_NAME:
         g_free (snap->name);
@@ -870,6 +938,10 @@ snapd_snap_set_property (GObject *object, guint prop_id, const GValue *value, GP
         g_free (snap->summary);
         snap->summary = g_strdup (g_value_get_string (value));
         break;
+    case PROP_TITLE:
+        g_free (snap->title);
+        snap->title = g_strdup (g_value_get_string (value));
+        break;
     case PROP_TRACKING_CHANNEL:
         g_free (snap->tracking_channel);
         snap->tracking_channel = g_strdup (g_value_get_string (value));
@@ -908,6 +980,9 @@ snapd_snap_get_property (GObject *object, guint prop_id, GValue *value, GParamSp
     case PROP_APPS:
         g_value_set_boxed (value, snap->apps);
         break;
+    case PROP_BASE:
+        g_value_set_string (value, snap->base);
+        break;
     case PROP_BROKEN:
         g_value_set_string (value, snap->broken);
         break;
@@ -947,8 +1022,11 @@ snapd_snap_get_property (GObject *object, guint prop_id, GValue *value, GParamSp
     case PROP_JAILMODE:
         g_value_set_boolean (value, snap->jailmode);
         break;
-    case PROP_TITLE:
-        g_value_set_string (value, snap->title);
+    case PROP_MEDIA:
+        g_value_set_boxed (value, snap->media);
+        break;
+    case PROP_MOUNTED_FROM:
+        g_value_set_string (value, snap->mounted_from);
         break;
     case PROP_NAME:
         g_value_set_string (value, snap->name);
@@ -987,6 +1065,9 @@ snapd_snap_get_property (GObject *object, guint prop_id, GValue *value, GParamSp
     case PROP_SUMMARY:
         g_value_set_string (value, snap->summary);
         break;
+    case PROP_TITLE:
+        g_value_set_string (value, snap->title);
+        break;
     case PROP_TRACKING_CHANNEL:
         g_value_set_string (value, snap->tracking_channel);
         break;
@@ -1017,6 +1098,7 @@ snapd_snap_finalize (GObject *object)
     SnapdSnap *snap = SNAPD_SNAP (object);
 
     g_clear_pointer (&snap->apps, g_ptr_array_unref);
+    g_clear_pointer (&snap->base, g_free);
     g_clear_pointer (&snap->broken, g_free);
     g_clear_pointer (&snap->channel, g_free);
     g_clear_pointer (&snap->channels, g_ptr_array_unref);
@@ -1028,6 +1110,8 @@ snapd_snap_finalize (GObject *object)
     g_clear_pointer (&snap->install_date, g_date_time_unref);
     g_clear_pointer (&snap->name, g_free);
     g_clear_pointer (&snap->license, g_free);
+    g_clear_pointer (&snap->media, g_ptr_array_unref);
+    g_clear_pointer (&snap->mounted_from, g_free);
     g_clear_pointer (&snap->prices, g_ptr_array_unref);
     g_clear_pointer (&snap->publisher_display_name, g_free);
     g_clear_pointer (&snap->publisher_id, g_free);
@@ -1059,6 +1143,13 @@ snapd_snap_class_init (SnapdSnapClass *klass)
                                                          "Apps this snap contains",
                                                          G_TYPE_PTR_ARRAY,
                                                          G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+    g_object_class_install_property (gobject_class,
+                                     PROP_BASE,
+                                     g_param_spec_string ("base",
+                                                          "base",
+                                                          "Base snap this snap uses",
+                                                          NULL,
+                                                          G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
     g_object_class_install_property (gobject_class,
                                      PROP_BROKEN,
                                      g_param_spec_string ("broken",
@@ -1172,10 +1263,17 @@ snapd_snap_class_init (SnapdSnapClass *klass)
                                                           NULL,
                                                           G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
     g_object_class_install_property (gobject_class,
-                                     PROP_TITLE,
-                                     g_param_spec_string ("title",
-                                                          "title",
-                                                          "The snap title",
+                                     PROP_MEDIA,
+                                     g_param_spec_boxed ("media",
+                                                         "media",
+                                                         "Media associated with this snap",
+                                                         G_TYPE_PTR_ARRAY,
+                                                         G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+    g_object_class_install_property (gobject_class,
+                                     PROP_MOUNTED_FROM,
+                                     g_param_spec_string ("mounted-from",
+                                                          "mounted-from",
+                                                          "Path snap is mounted from",
                                                           NULL,
                                                           G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
     g_object_class_install_property (gobject_class,
@@ -1255,6 +1353,13 @@ snapd_snap_class_init (SnapdSnapClass *klass)
                                                           "One line description",
                                                           NULL,
                                                           G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+    g_object_class_install_property (gobject_class,
+                                     PROP_TITLE,
+                                     g_param_spec_string ("title",
+                                                          "title",
+                                                          "The snap title",
+                                                          NULL,
+                                                          G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
     g_object_class_install_property (gobject_class,
                                      PROP_TRACKING_CHANNEL,
                                      g_param_spec_string ("tracking-channel",
