@@ -34,6 +34,7 @@ struct _SnapdSystemInformation
     GObject parent_instance;
 
     gchar *binaries_directory;
+    gchar *build_id;
     SnapdSystemConfinement confinement;
     gchar *kernel_version;
     gboolean on_classic;
@@ -41,6 +42,12 @@ struct _SnapdSystemInformation
     gchar *mount_directory;
     gchar *os_id;
     gchar *os_version;
+    GDateTime *refresh_hold;
+    GDateTime *refresh_last;
+    GDateTime *refresh_next;
+    gchar *refresh_schedule;
+    gchar *refresh_timer;
+    GHashTable *sandbox_features;
     gchar *series;
     gchar *store;
     gchar *version;
@@ -59,6 +66,13 @@ enum
     PROP_BINARIES_DIRECTORY,
     PROP_MOUNT_DIRECTORY,
     PROP_CONFINEMENT,
+    PROP_BUILD_ID,
+    PROP_SANDBOX_FEATURES,
+    PROP_REFRESH_HOLD,
+    PROP_REFRESH_LAST,
+    PROP_REFRESH_NEXT,
+    PROP_REFRESH_SCHEDULE,
+    PROP_REFRESH_TIMER,
     PROP_LAST
 };
 
@@ -81,6 +95,23 @@ snapd_system_information_get_binaries_directory (SnapdSystemInformation *system_
     return system_information->binaries_directory;
 }
 
+/**
+ * snapd_system_information_get_build_id:
+ * @system_information: a #SnapdSystemInformation.
+ *
+ * Gets the unique build ID for the snap build, e.g. "efdd0b5e69b0742fa5e5bad0771df4d1df2459d1"
+ *
+ * Returns: a build ID.
+ *
+ * Since: 1.40
+ */
+const gchar *
+snapd_system_information_get_build_id (SnapdSystemInformation *system_information)
+{
+    g_return_val_if_fail (SNAPD_IS_SYSTEM_INFORMATION (system_information), NULL);
+    return system_information->build_id;
+}
+
 /**
  * snapd_system_information_get_confinement:
  * @system_information: a #SnapdSystemInformation.
@@ -200,6 +231,110 @@ snapd_system_information_get_os_version (SnapdSystemInformation *system_informat
     return system_information->os_version;
 }
 
+/**
+ * snapd_system_information_get_refresh_hold:
+ * @system_information: a #SnapdSystemInformation.
+ *
+ * Get the time refreshes will be applied at, or %NULL if they are applied immediately.
+ *
+ * Returns: (transfer none) (allow-none): a #GDateTime.
+ *
+ * Since: 1.42
+ */
+GDateTime *
+snapd_system_information_get_refresh_hold (SnapdSystemInformation *system_information)
+{
+    g_return_val_if_fail (SNAPD_IS_SYSTEM_INFORMATION (system_information), NULL);
+    return system_information->refresh_hold;
+}
+
+/**
+ * snapd_system_information_get_refresh_last:
+ * @system_information: a #SnapdSystemInformation.
+ *
+ * Get the time the last refresh occurred, or %NULL if has not occurred.
+ *
+ * Returns: (transfer none) (allow-none): a #GDateTime.
+ *
+ * Since: 1.42
+ */
+GDateTime *
+snapd_system_information_get_refresh_last (SnapdSystemInformation *system_information)
+{
+    g_return_val_if_fail (SNAPD_IS_SYSTEM_INFORMATION (system_information), NULL);
+    return system_information->refresh_last;
+}
+
+/**
+ * snapd_system_information_get_refresh_next:
+ * @system_information: a #SnapdSystemInformation.
+ *
+ * Get the time the next refresh is scheduled for, or %NULL if none has been scheduled.
+ *
+ * Returns: (transfer none) (allow-none): a #GDateTime.
+ *
+ * Since: 1.42
+ */
+GDateTime *
+snapd_system_information_get_refresh_next (SnapdSystemInformation *system_information)
+{
+    g_return_val_if_fail (SNAPD_IS_SYSTEM_INFORMATION (system_information), NULL);
+    return system_information->refresh_next;
+}
+
+/**
+ * snapd_system_information_get_refresh_schedule:
+ * @system_information: a #SnapdSystemInformation.
+ *
+ * Get the schedule when snap refreshes will occur.
+ *
+ * Returns: (allow-none): a Snap refresh schedule string.
+ *
+ * Since: 1.42
+ */
+const gchar *
+snapd_system_information_get_refresh_schedule (SnapdSystemInformation *system_information)
+{
+    g_return_val_if_fail (SNAPD_IS_SYSTEM_INFORMATION (system_information), NULL);
+    return system_information->refresh_schedule;
+}
+
+/**
+ * snapd_system_information_get_refresh_timer:
+ * @system_information: a #SnapdSystemInformation.
+ *
+ * Get the timer that refreshes are running to.
+ *
+ * Returns: (allow-none): a Snap refresh timer string.
+ *
+ * Since: 1.42
+ */
+const gchar *
+snapd_system_information_get_refresh_timer (SnapdSystemInformation *system_information)
+{
+    g_return_val_if_fail (SNAPD_IS_SYSTEM_INFORMATION (system_information), NULL);
+    return system_information->refresh_timer;
+}
+
+/**
+ * snapd_system_information_get_sandbox_features:
+ * @system_information: a #SnapdSystemInformation.
+ *
+ * Gets the sandbox features that snapd provides. Each backend in snapd provides
+ * a list of features that it supports. For example, the "confinement-options"
+ * backend may provide "classic", "devmode" and "strict".
+ *
+ * Returns: (transfer none) (element-type utf8 GStrv): a hash table of string arrays keyed by backend name.
+ *
+ * Since: 1.42
+ */
+GHashTable *
+snapd_system_information_get_sandbox_features (SnapdSystemInformation *system_information)
+{
+    g_return_val_if_fail (SNAPD_IS_SYSTEM_INFORMATION (system_information), NULL);
+    return system_information->sandbox_features;
+}
+
 /**
  * snapd_system_information_get_series:
  * @system_information: a #SnapdSystemInformation.
@@ -261,6 +396,10 @@ snapd_system_information_set_property (GObject *object, guint prop_id, const GVa
         g_free (system_information->binaries_directory);
         system_information->binaries_directory = g_strdup (g_value_get_string (value));
         break;
+    case PROP_BUILD_ID:
+        g_free (system_information->build_id);
+        system_information->build_id = g_strdup (g_value_get_string (value));
+        break;
     case PROP_CONFINEMENT:
         system_information->confinement = g_value_get_enum (value);
         break;
@@ -286,6 +425,33 @@ snapd_system_information_set_property (GObject *object, guint prop_id, const GVa
         g_free (system_information->os_version);
         system_information->os_version = g_strdup (g_value_get_string (value));
         break;
+    case PROP_REFRESH_HOLD:
+        g_clear_pointer (&system_information->refresh_hold, g_date_time_unref);
+        if (g_value_get_boxed (value) != NULL)
+            system_information->refresh_hold = g_date_time_ref (g_value_get_boxed (value));
+        break;
+    case PROP_REFRESH_LAST:
+        g_clear_pointer (&system_information->refresh_last, g_date_time_unref);
+        if (g_value_get_boxed (value) != NULL)
+            system_information->refresh_last = g_date_time_ref (g_value_get_boxed (value));
+        break;
+    case PROP_REFRESH_NEXT:
+        g_clear_pointer (&system_information->refresh_next, g_date_time_unref);
+        if (g_value_get_boxed (value) != NULL)
+            system_information->refresh_next = g_date_time_ref (g_value_get_boxed (value));
+        break;
+    case PROP_REFRESH_SCHEDULE:
+        g_free (system_information->refresh_schedule);
+        system_information->refresh_schedule = g_strdup (g_value_get_string (value));
+        break;
+    case PROP_REFRESH_TIMER:
+        g_free (system_information->refresh_timer);
+        system_information->refresh_timer = g_strdup (g_value_get_string (value));
+        break;
+    case PROP_SANDBOX_FEATURES:
+        g_hash_table_unref (system_information->sandbox_features);
+        system_information->sandbox_features = g_hash_table_ref (g_value_get_pointer (value));
+        break;
     case PROP_SERIES:
         g_free (system_information->series);
         system_information->series = g_strdup (g_value_get_string (value));
@@ -313,6 +479,9 @@ snapd_system_information_get_property (GObject *object, guint prop_id, GValue *v
     case PROP_BINARIES_DIRECTORY:
         g_value_set_string (value, system_information->binaries_directory);
         break;
+    case PROP_BUILD_ID:
+        g_value_set_string (value, system_information->build_id);
+        break;
     case PROP_CONFINEMENT:
         g_value_set_enum (value, system_information->confinement);
         break;
@@ -334,6 +503,24 @@ snapd_system_information_get_property (GObject *object, guint prop_id, GValue *v
     case PROP_OS_VERSION:
         g_value_set_string (value, system_information->os_version);
         break;
+    case PROP_REFRESH_HOLD:
+        g_value_set_boxed (value, system_information->refresh_hold);
+        break;
+    case PROP_REFRESH_LAST:
+        g_value_set_boxed (value, system_information->refresh_last);
+        break;
+    case PROP_REFRESH_NEXT:
+        g_value_set_boxed (value, system_information->refresh_next);
+        break;
+    case PROP_REFRESH_SCHEDULE:
+        g_value_set_string (value, system_information->refresh_schedule);
+        break;
+    case PROP_REFRESH_TIMER:
+        g_value_set_string (value, system_information->refresh_timer);
+        break;
+    case PROP_SANDBOX_FEATURES:
+        g_value_set_pointer (value, system_information->sandbox_features);
+        break;
     case PROP_SERIES:
         g_value_set_string (value, system_information->series);
         break;
@@ -355,10 +542,17 @@ snapd_system_information_finalize (GObject *object)
     SnapdSystemInformation *system_information = SNAPD_SYSTEM_INFORMATION (object);
 
     g_clear_pointer (&system_information->binaries_directory, g_free);
+    g_clear_pointer (&system_information->build_id, g_free);
     g_clear_pointer (&system_information->kernel_version, g_free);
     g_clear_pointer (&system_information->mount_directory, g_free);
     g_clear_pointer (&system_information->os_id, g_free);
     g_clear_pointer (&system_information->os_version, g_free);
+    g_clear_pointer (&system_information->refresh_hold, g_date_time_unref);
+    g_clear_pointer (&system_information->refresh_last, g_date_time_unref);
+    g_clear_pointer (&system_information->refresh_next, g_date_time_unref);
+    g_clear_pointer (&system_information->refresh_schedule, g_free);
+    g_clear_pointer (&system_information->refresh_timer, g_free);
+    g_clear_pointer (&system_information->sandbox_features, g_hash_table_unref);
     g_clear_pointer (&system_information->series, g_free);
     g_clear_pointer (&system_information->store, g_free);
     g_clear_pointer (&system_information->version, g_free);
@@ -382,6 +576,13 @@ snapd_system_information_class_init (SnapdSystemInformationClass *klass)
                                                           "Directory with snap binaries",
                                                           NULL,
                                                           G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+    g_object_class_install_property (gobject_class,
+                                     PROP_BUILD_ID,
+                                     g_param_spec_string ("build-id",
+                                                          "build-id",
+                                                          "Unique build ID for snap build",
+                                                          NULL,
+                                                          G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
     g_object_class_install_property (gobject_class,
                                      PROP_CONFINEMENT,
                                      g_param_spec_enum ("confinement",
@@ -431,6 +632,47 @@ snapd_system_information_class_init (SnapdSystemInformationClass *klass)
                                                           "Operating system version",
                                                           NULL,
                                                           G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+    g_object_class_install_property (gobject_class,
+                                     PROP_REFRESH_HOLD,
+                                     g_param_spec_boxed ("refresh-hold",
+                                                         "refresh-hold",
+                                                         "Time refreshes will be applied",
+                                                         G_TYPE_DATE_TIME,
+                                                         G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+    g_object_class_install_property (gobject_class,
+                                     PROP_REFRESH_LAST,
+                                     g_param_spec_boxed ("refresh-last",
+                                                         "refresh-last",
+                                                         "Last time a refresh occurred",
+                                                         G_TYPE_DATE_TIME,
+                                                         G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+    g_object_class_install_property (gobject_class,
+                                     PROP_REFRESH_NEXT,
+                                     g_param_spec_boxed ("refresh-next",
+                                                         "refresh-next",
+                                                         "Next time a refresh is scheduled for",
+                                                         G_TYPE_DATE_TIME,
+                                                         G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+    g_object_class_install_property (gobject_class,
+                                     PROP_REFRESH_SCHEDULE,
+                                     g_param_spec_string ("refresh-schedule",
+                                                          "refresh-schedule",
+                                                          "Refresh schedule",
+                                                          NULL,
+                                                          G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+    g_object_class_install_property (gobject_class,
+                                     PROP_REFRESH_TIMER,
+                                     g_param_spec_string ("refresh-timer",
+                                                          "refresh-timer",
+                                                          "Refresh timer",
+                                                          NULL,
+                                                          G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+    g_object_class_install_property (gobject_class,
+                                     PROP_SANDBOX_FEATURES,
+                                     g_param_spec_pointer ("sandbox-features",
+                                                           "sandbox-features",
+                                                           "Sandbox features",
+                                                           G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
     g_object_class_install_property (gobject_class,
                                      PROP_SERIES,
                                      g_param_spec_string ("series",
@@ -457,4 +699,5 @@ snapd_system_information_class_init (SnapdSystemInformationClass *klass)
 static void
 snapd_system_information_init (SnapdSystemInformation *system_information)
 {
+    system_information->sandbox_features = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, (GDestroyNotify) g_strfreev);
 }
