@@ -16,6 +16,7 @@
 #include <Snapd/Enums>
 #include <Snapd/App>
 #include <Snapd/Channel>
+#include <Snapd/Media>
 #include <Snapd/Price>
 #include <Snapd/Screenshot>
 
@@ -24,6 +25,7 @@ class Q_DECL_EXPORT QSnapdSnap : public QSnapdWrappedObject
     Q_OBJECT
 
     Q_PROPERTY(int appCount READ appCount)
+    Q_PROPERTY(QString base READ base)
     Q_PROPERTY(QString broken READ broken)
     Q_PROPERTY(QString channel READ channel)
     Q_PROPERTY(int channelCount READ channelCount)
@@ -40,6 +42,7 @@ class Q_DECL_EXPORT QSnapdSnap : public QSnapdWrappedObject
     Q_PROPERTY(qint64 installedSize READ installedSize)
     Q_PROPERTY(bool jailmode READ jailmode)
     Q_PROPERTY(QString license READ license)
+    Q_PROPERTY(QString mountedFrom READ mountedFrom)
     Q_PROPERTY(QString name READ name)
     Q_PROPERTY(int priceCount READ priceCount)
     Q_PROPERTY(bool isPrivate READ isPrivate)
@@ -62,6 +65,7 @@ public:
 
     int appCount () const;
     Q_INVOKABLE QSnapdApp *app (int) const;
+    QString base () const;
     QString broken () const;
     QString channel () const;
     int channelCount () const;
@@ -80,6 +84,9 @@ public:
     qint64 installedSize () const;
     bool jailmode () const;
     QString license () const;
+    int mediaCount () const;
+    Q_INVOKABLE QSnapdMedia *media (int) const;
+    QString mountedFrom () const;
     QString name () const;
     int priceCount () const;
     Q_INVOKABLE QSnapdPrice *price (int) const;
@@ -89,8 +96,8 @@ public:
     QString publisherUsername () const;
     QSnapdEnums::PublisherValidation publisherValidation () const;
     QString revision () const;
-    int screenshotCount () const;
-    Q_INVOKABLE QSnapdScreenshot *screenshot (int) const;
+    Q_DECL_DEPRECATED_X("Use mediaCount()") int screenshotCount () const;
+    Q_DECL_DEPRECATED_X("Use media()") QSnapdScreenshot *screenshot (int) const;
     QSnapdEnums::SnapType snapType () const;
     QSnapdEnums::SnapStatus status () const;
     QString summary () const;
