@@ -58,6 +58,9 @@ QSnapdTask *QSnapdChange::task (int n) const
 
 static QDateTime convertDateTime (GDateTime *datetime)
 {
+    if (datetime == NULL)
+        return QDateTime ();
+
     QDate date (g_date_time_get_year (datetime),
                 g_date_time_get_month (datetime),
                 g_date_time_get_day_of_month (datetime));
@@ -77,3 +80,8 @@ QDateTime QSnapdChange::readyTime () const
 {
     return convertDateTime (snapd_change_get_ready_time (SNAPD_CHANGE (wrapped_object)));
 }
+
+QString QSnapdChange::error () const
+{
+    return snapd_change_get_error (SNAPD_CHANGE (wrapped_object));
+}
