@@ -151,14 +151,15 @@ public:
 class QSnapdGetAppsRequestPrivate
 {
 public:
-    QSnapdGetAppsRequestPrivate (int flags) :
-        flags(flags) {}
+    QSnapdGetAppsRequestPrivate (int flags, const QStringList& snaps) :
+        flags(flags), filter_snaps(snaps) {}
     ~QSnapdGetAppsRequestPrivate ()
     {
         if (apps != NULL)
             g_ptr_array_unref (apps);
     }
     int flags;
+    QStringList filter_snaps;
     GPtrArray *apps = NULL;
 };
 
@@ -187,7 +188,7 @@ public:
             g_strfreev (assertions);
     }
     QString type;
-    gchar **assertions = NULL;
+    GStrv assertions = NULL;
 };
 
 class QSnapdAddAssertionsRequestPrivate
@@ -317,7 +318,7 @@ public:
         if (snap_names != NULL)
             g_strfreev (snap_names);
     }
-    gchar **snap_names = NULL;
+    GStrv snap_names = NULL;
 };
 
 class QSnapdRemoveRequestPrivate
@@ -414,7 +415,7 @@ public:
         if (sections != NULL)
             g_strfreev (sections);
     }
-    gchar **sections = NULL;
+    GStrv sections = NULL;
 };
 
 class QSnapdGetAliasesRequestPrivate
