@@ -150,6 +150,18 @@ void QSnapdRequest::finish (void *error)
             case SNAPD_ERROR_AUTH_CANCELLED:
                 d->error = QSnapdRequest::QSnapdError::AuthCancelled;
                 break;
+            case SNAPD_ERROR_NOT_CLASSIC:
+                d->error = QSnapdRequest::QSnapdError::NotClassic;
+                break;
+            case SNAPD_ERROR_REVISION_NOT_AVAILABLE:
+                d->error = QSnapdRequest::QSnapdError::RevisionNotAvailable;
+                break;
+            case SNAPD_ERROR_CHANNEL_NOT_AVAILABLE:
+                d->error = QSnapdRequest::QSnapdError::ChannelNotAvailable;
+                break;
+            case SNAPD_ERROR_NOT_A_SNAP:
+                d->error = QSnapdRequest::QSnapdError::NotASnap;
+                break;
             default:
                 /* This indicates we should add a new entry here... */
                 d->error = QSnapdRequest::QSnapdError::UnknownError;
