@@ -30,9 +30,9 @@ typedef struct _MockAlias MockAlias;
 typedef struct _MockApp MockApp;
 typedef struct _MockChange MockChange;
 typedef struct _MockChannel MockChannel;
+typedef struct _MockMedia MockMedia;
 typedef struct _MockPlug MockPlug;
 typedef struct _MockPrice MockPrice;
-typedef struct _MockScreenshot MockScreenshot;
 typedef struct _MockSlot MockSlot;
 typedef struct _MockSnap MockSnap;
 typedef struct _MockTask MockTask;
@@ -53,6 +53,10 @@ gboolean        mock_snapd_start                  (MockSnapd     *snapd,
 
 void            mock_snapd_stop                   (MockSnapd     *snapd);
 
+void            mock_snapd_set_maintenance        (MockSnapd     *snapd,
+                                                   const gchar   *type,
+                                                   const gchar   *message);
+
 void            mock_snapd_set_build_id           (MockSnapd     *snapd,
                                                    const gchar   *build_id);
 
@@ -112,7 +116,7 @@ void            mock_account_set_has_payment_methods (MockAccount   *account,
 
 const gchar    *mock_account_get_macaroon         (MockAccount   *account);
 
-gchar         **mock_account_get_discharges       (MockAccount   *account);
+GStrv           mock_account_get_discharges       (MockAccount   *account);
 
 gboolean        mock_account_get_sudoer           (MockAccount   *account);
 
@@ -122,7 +126,7 @@ void            mock_account_set_otp              (MockAccount   *account,
                                                    const gchar   *otp);
 
 void            mock_account_set_ssh_keys         (MockAccount   *account,
-                                                   gchar        **ssh_keys);
+                                                   GStrv          ssh_keys);
 
 MockAccount    *mock_snapd_find_account_by_username (MockSnapd     *snapd,
                                                      const gchar   *username);
@@ -203,6 +207,9 @@ void            mock_app_add_manual_alias         (MockApp       *app,
 MockAlias      *mock_app_find_alias               (MockApp       *app,
                                                    const gchar   *name);
 
+void            mock_snap_set_base                (MockSnap      *snap,
+                                                   const gchar   *base);
+
 void            mock_snap_set_broken              (MockSnap      *snap,
                                                    const gchar   *broken);
 
@@ -294,6 +301,9 @@ gboolean        mock_snap_get_jailmode            (MockSnap      *snap);
 void            mock_snap_set_license             (MockSnap      *snap,
                                                    const gchar   *license);
 
+void            mock_snap_set_mounted_from        (MockSnap      *snap,
+                                                   const gchar   *mounted_from);
+
 const gchar    *mock_snap_get_path                (MockSnap      *snap);
 
 gboolean        mock_snap_get_preferred           (MockSnap      *snap);
@@ -325,7 +335,8 @@ const gchar    *mock_snap_get_revision            (MockSnap      *snap);
 void            mock_snap_set_scope_is_wide       (MockSnap      *snap,
                                                    gboolean       scope_is_wide);
 
-MockScreenshot *mock_snap_add_screenshot          (MockSnap      *snap,
+MockMedia      *mock_snap_add_media               (MockSnap      *snap,
+                                                   const gchar   *type,
                                                    const gchar   *url,
                                                    int            width,
                                                    int            height);
